pub struct AddDocumentParams {
pub content: String,
pub source: Option<String>,
}Fields
content: Stringsource: Option<String>Trait Implementations
Sourceimpl Debug for AddDocumentParams
impl Debug for AddDocumentParams
Sourceimpl<'de> Deserialize<'de> for AddDocumentParams
impl<'de> Deserialize<'de> for AddDocumentParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AddDocumentParams
impl JsonSchema for AddDocumentParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AddDocumentParams
impl RefUnwindSafe for AddDocumentParams
impl Send for AddDocumentParams
impl Sync for AddDocumentParams
impl Unpin for AddDocumentParams
impl UnsafeUnpin for AddDocumentParams
impl UnwindSafe for AddDocumentParams